@@ -57,9 +57,9 @@ sub OpenLog($) {
 	if ($@) {
 	    die "Cannot open Syslog: $@";
 	}
-	if ($^O ne 'solaris'  &&
+	if ($^O ne 'solaris'  &&  $^O ne 'freebsd'  &&
 	    defined(&Sys::Syslog::setlogsock)  &&
-	    defined(&Sys::Syslog::_PATH_LOG)) {
+	    eval { &Sys::Syslog::_PATH_LOG() }) {
 	    &Sys::Syslog::setlogsock('unix');
 	}
 	&Sys::Syslog::openlog($self->{'logname'} || ref($self), 'pid',
